package com.idtech.demo;

import com.idtech.bluetooth.IDTechOpenHelper;
import com.idtech.bluetooth.IDTechReader;
import com.idtech.bluetooth.IDTechUtils;
import com.idtech.bluetooth.OnReceiveListener;

import android.app.Activity;
import android.content.res.Configuration;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;
import android.widget.ToggleButton;

//First,implement interface OnReceiveListener
public class BluetoothDemoActivity extends Activity implements OnReceiveListener {
	
	EditText mEditText = null;
	TextView mStatus = null;
	IDTechOpenHelper mIDTechHelper = null;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.bluetooth_demo);
		mEditText = (EditText) findViewById(R.id.demo_edittext1);
		mStatus = (TextView) findViewById(R.id.demo_text4);
		mEditText.setText("");
		mStatus.setText("OFF");
		mEditText.setLongClickable(true);
		//Second,Create the object of IDTechOpenHelper
		mIDTechHelper = new IDTechOpenHelper(this);
		
		//Third,set the port for receiving msg.
		mIDTechHelper.setOnReceiveListener(this);
		
		Button connect = (Button) findViewById(R.id.demo_btn_3);
		Button clear = (Button) findViewById(R.id.demo_btn_4);
		ListView listview = (ListView) findViewById(R.id.function_listview);
		connect.setOnClickListener(new View.OnClickListener() {
			public void onClick(View v) {
				//Fourth, connect the bluetooth.
				mIDTechHelper.onCreatedDeviceOption();
				
			}
		});
		clear.setOnClickListener(new View.OnClickListener() {
			public void onClick(View v) {
				
				mEditText.setText("");
			//	mIDTechHelper.close();
				
			}
		});
		
		
		String[] items = getResources().getStringArray(R.array.functions);
		ArrayAdapter<String> adapter = new ArrayAdapter<String>(this, 
				android.R.layout.simple_list_item_1, items);
		listview.setAdapter(adapter);
		listview.setOnItemClickListener(itemClickListener);
	}

	/**
	 * 
	 */
	private AdapterView.OnItemClickListener itemClickListener = 
				new AdapterView.OnItemClickListener() {
		public void onItemClick(AdapterView<?> av, View v, int which, long id) {
			switch (which) {//The funcitons order for arrary.xml.
			case 0 :
				mIDTechHelper.setMSRReading(IDTechReader.MSR_READING_ENABLE);
				break;
			case 1 :
				mIDTechHelper.setMSRReading(IDTechReader.MSR_READING_DISABLE);
				break;
			case 2 :
				mIDTechHelper.review();
				break;
			case 3 :
				mIDTechHelper.reviewFirmwareVersion();
				break;
			case 4 :
				mIDTechHelper.reviewKSN();
				break;
			case 5 :
				mIDTechHelper.reviewSecurityLevel();
				break;
			case 6 :
				mIDTechHelper.reviewSerialNumber();
				break;
			case 7 :
				mIDTechHelper.setDecodingMethodReview(
				IDTechReader.DECODING_METHOD_REVIEW_CMD, true);
				break;
			case 8 :
				mIDTechHelper.setEncryptionReview(
				IDTechReader.ENCRYPTION_REVIEW_CMD, true);
				break;
			case 9 :
				mIDTechHelper.setKeyManagementTypeReview(
				IDTechReader.KEY_MANAGEMENT_REVIEW_CMD, true);
				break;
			case 10 :
				mIDTechHelper.setMagneticTrackReview(
						IDTechReader.SELECT_MAGNETIC_TRACK_REVIEW_CMD, true);
				break;
			case 11 :
				mIDTechHelper.setMagneticTrackSeparatorReview(
						IDTechReader.TRACK_SEPARATOR_REVIEW_CMD, true);
				break;
			case 12 :
				mIDTechHelper.setTrackPrefixReview();
				break;
			case 13 :
				mIDTechHelper.setTrackSuffixReview();
				break;
			case 14 :
				mIDTechHelper.setTerminatorReview(
						IDTechReader.TERMINATOR_REVIEW_CMD, true);
				break;
			case 15 :
				mIDTechHelper.inputMethod(IDTechOpenHelper.INPUT_METHOD_PREFIX);
				break;
			case 16 :
				mIDTechHelper.inputMethod(IDTechOpenHelper.INPUT_METHOD_SUFFIX);
				break;
			case 17 :
				mIDTechHelper.setDefault();
				break;
			default : break;
			}
		}
	};
	@Override
	public void onConfigurationChanged(Configuration newConfig){
		super.onConfigurationChanged(newConfig);
		if(this.getResources().getConfiguration().orientation == Configuration.ORIENTATION_LANDSCAPE){
			//land do nothing is ok
			
		}else if(this.getResources().getConfiguration().orientation == Configuration.ORIENTATION_PORTRAIT ){
			
			//port do nothing is ok
		}
		
	}
	@Override
	protected void onDestroy() {
		//Colse the connection when exit
		
		mIDTechHelper.close();
		super.onDestroy();
	}

	//Implement the method of interface OnReceiveListener.
	
	
	public void onConnecting() {
		Toast.makeText(this, "Connecting..please wait", 0).show();
	}


	public void onConnectedError(int errorType, String errorMsg) {
		Toast.makeText(this, "Connect errorfor[" + errorMsg + "]", 0).show();
	}


	public void onDisconnected() {
		Toast.makeText(this, "BlueTooth device is unconnected", 0).show();
	}


	public void onReceivedData(int funcType, byte[] reviewDatas) {
		switch (funcType) {
		//TODO 
		case IDTechReader.TYPE_OF_DECODING :
			break;
		case IDTechReader.TYPE_OF_ENCRYPTION :
			break;
		case IDTechReader.TYPE_OF_KEY_MANAGEMENT :
			break;
		case IDTechReader.TYPE_OF_POSTAMBLE :
			break;
		case IDTechReader.TYPE_OF_PREAMBLE :
			break;
		case IDTechReader.TYPE_OF_PREFIX :
			break;
		case IDTechReader.TYPE_OF_SUFFIX :
			break;
		case IDTechReader.TYPE_OF_TERMINATOR :
			break;
		case IDTechReader.TYPE_OF_TRACK2 :
			break;
		case IDTechReader.TYPE_OF_TRACK_SELECTION :
			break;
		case IDTechReader.TYPE_OF_TRACK_SEPARATOR :
			break;
		case IDTechReader.TYPE_OF_REVIEW :
			break;
		case IDTechReader.TYPE_OF_REVIEW_FIRMWARE_VERSION :
			break;
		case IDTechReader.TYPE_OF_REVIEW_KSN :
			break;
		case IDTechReader.TYPE_OF_REVIEW_SECURITY_LEVEL :
			break;
		case IDTechReader.TYPE_OF_REVIEW_SERIAL_NUMBER :
			break;
		default : break;
		}
		//Show data.
		String Result = "\n"; 
		Result += new String(reviewDatas, 0, reviewDatas.length);
		Result += "\n";
		mEditText.setText(mEditText.getText().toString() 
			+ IDTechUtils.byteToHexString(reviewDatas) + Result);
	}

	
	public void onReceivedFailed(int funcType) {
		switch (funcType) {
		//TODO 
		case IDTechReader.TYPE_OF_MSR_READING_DISABLE :
			break;
		case IDTechReader.TYPE_OF_MSR_READING_ENABLE :
			break;
		case IDTechReader.TYPE_OF_DECODING :
			break;
		case IDTechReader.TYPE_OF_DEFAULT :
			break;
		case IDTechReader.TYPE_OF_ENCRYPTION :
			break;
		case IDTechReader.TYPE_OF_KEY_MANAGEMENT :
			break;
		case IDTechReader.TYPE_OF_POSTAMBLE :
			break;
		case IDTechReader.TYPE_OF_PREAMBLE :
			break;
		case IDTechReader.TYPE_OF_PREFIX :
			break;
		case IDTechReader.TYPE_OF_SUFFIX :
			break;
		case IDTechReader.TYPE_OF_TERMINATOR :
			break;
		case IDTechReader.TYPE_OF_TRACK2 :
			break;
		case IDTechReader.TYPE_OF_TRACK_SELECTION :
			break;
		case IDTechReader.TYPE_OF_TRACK_SEPARATOR :
			break;
		default : break;
		}
		//The msg will show if handle fail.
		
		Toast.makeText(this, "Operation failed", 0).show();
		
	}


	public void onReceivedSuccess(int funcType) {
		switch (funcType) {
		//TODO 
		case IDTechReader.TYPE_OF_MSR_READING_DISABLE :
			mStatus.setText("OFF");
			break;
		case IDTechReader.TYPE_OF_MSR_READING_ENABLE :
			mStatus.setText("ON");
			break;
		case IDTechReader.TYPE_OF_DECODING : 
			break;
		case IDTechReader.TYPE_OF_DEFAULT :
			break;
		case IDTechReader.TYPE_OF_ENCRYPTION :
			break;
		case IDTechReader.TYPE_OF_KEY_MANAGEMENT :
			break;
		case IDTechReader.TYPE_OF_POSTAMBLE :
			break;
		case IDTechReader.TYPE_OF_PREAMBLE :
			break;
		case IDTechReader.TYPE_OF_PREFIX :
			break;
		case IDTechReader.TYPE_OF_SUFFIX :
			break;
		case IDTechReader.TYPE_OF_TERMINATOR :
			break;
		case IDTechReader.TYPE_OF_TRACK2 :
			break;
		case IDTechReader.TYPE_OF_TRACK_SELECTION :
			break;
		case IDTechReader.TYPE_OF_TRACK_SEPARATOR :
			break;
		default : break;
		}
		//
		Toast.makeText(this, "Operation success", 0).show();
	}

	public void onConnected() {
		// TODO Auto-generated method stub
		Toast.makeText(this, "Connect Success", 0).show();
	}

}